/*
 * The MIT License (MIT)
 *
 * Copyright © 2023 xrv <xrv@live.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.tzld.crawler.etl.common;


import org.springframework.validation.BeanPropertyBindingResult;
import org.springframework.validation.Errors;
import org.springframework.validation.Validator;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.ValidatorFactory;
import java.util.Set;
import java.util.StringJoiner;

/**
 * @author ehlxr
 * @since 2023-07-14 15:18.
 */
public class CustomValidator implements Validator {
    private final javax.validation.Validator validator;

    public CustomValidator() {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    }

    public static Result validate(Object param) {
        Validator validator = new CustomValidator();
        BeanPropertyBindingResult errors = new BeanPropertyBindingResult(param, "param");
        validator.validate(param, errors);
        if (errors.hasErrors()) {
            StringJoiner errorMessage = new StringJoiner("; ", "[", "]");
            errors.getAllErrors().forEach(e -> errorMessage.add(e.getDefaultMessage()));
            return Result.error(errorMessage.toString());
        }

        return Result.success();
    }

    public static class Result {
        boolean success;
        String message;

        public Result(boolean success, String message) {
            this.success = success;
            this.message = message;
        }

        public static Result success() {
            return new Result(true, "");
        }

        public static Result error(String message) {
            return new Result(false, message);
        }

        public boolean notSuccess() {
            return !success;
        }

        public String getMessage() {
            return message;
        }
    }

    @Override
    public boolean supports(Class<?> clazz) {
        return (this.validator != null);
    }

    @Override
    public void validate(Object target, Errors errors) {
        Set<ConstraintViolation<Object>> constraintViolations = validator.validate(target);
        for (ConstraintViolation<Object> violation : constraintViolations) {
            String field = violation.getPropertyPath().toString();
            String message = violation.getMessage();
            errors.rejectValue(field, "", message);
        }
    }
}
