/*
 * The MIT License (MIT)
 *
 * Copyright © 2022 xrv <xrg@live.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.tzld.crawler.etl.config;

import com.google.common.base.Strings;
import io.swagger.v3.oas.models.OpenAPI;
import io.swagger.v3.oas.models.servers.Server;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import springfox.documentation.oas.web.OpenApiTransformationContext;
import springfox.documentation.oas.web.WebMvcOpenApiTransformationFilter;
import springfox.documentation.spi.DocumentationType;

import javax.servlet.http.HttpServletRequest;
import java.util.Collections;

/**
 * @author ehlxr
 * @since 2022-02-10 11:00.
 * <p>
 * https://github.com/springfox/springfox/issues/3483
 * <p>
 * https://github.com/springfox/springfox/issues/3445
 */
@Component
public class SwaggerHostResolver implements WebMvcOpenApiTransformationFilter {
    @Value("${swagger.host:}")
    private String hostUri;

    @Value("${server.servlet.context-path:}")
    private String contextPath;

    @Override
    public OpenAPI transform(OpenApiTransformationContext<HttpServletRequest> context) {
        OpenAPI openApi = context.getSpecification();
        if (Strings.isNullOrEmpty(hostUri)) {
            context.request().ifPresent(httpServletRequest -> {
                String referer = httpServletRequest.getHeader("referer");
                if (!Strings.isNullOrEmpty(referer)) {
                    hostUri = referer.substring(0, referer.indexOf(contextPath));
                }
            });
        }

        Server server = new Server();
        server.setUrl(hostUri);
        openApi.setServers(Collections.singletonList(server));
        return openApi;
    }

    @Override
    public boolean supports(DocumentationType delimiter) {
        return delimiter == DocumentationType.OAS_30;
    }
}