package com.tzld.crawler.etl.filter;

import com.tzld.crawler.etl.common.base.Constant;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.slf4j.MDC;
import org.springframework.core.annotation.Order;

import javax.servlet.*;
import javax.servlet.annotation.WebFilter;
import java.io.IOException;
import java.util.UUID;

/**
 * 日志增加traceId
 *
 * @author supeng
 * @date 2020/08/25
 */
@Order(value = 1)
@WebFilter(filterName = "logTraceFilter", urlPatterns = "/*")
public class LogTraceFilter implements Filter {
    private static final Logger LOGGER = LoggerFactory.getLogger(LogTraceFilter.class);

    @Override
    public void init(FilterConfig filterConfig) {
        LOGGER.info("logTraceFilter init");
    }

    @Override
    public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain) throws IOException, ServletException {
        MDC.put(Constant.LOG_TRACE_ID, UUID.randomUUID().toString());
        filterChain.doFilter(servletRequest, servletResponse);
        MDC.remove(Constant.LOG_TRACE_ID);
    }

    @Override
    public void destroy() {
        LOGGER.info("logTraceFilter destroy");
    }
}
