/*
 * The MIT License (MIT)
 *
 * Copyright © 2023 xrv <xrv@live.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.tzld.crawler.etl.model.dto;

import com.tzld.crawler.etl.enums.MetricTypeEnum;

/**
 * 监控度量日志
 *
 * @author ehlxr
 * @since 2023-07-18 13:17.
 */
public class MetricLogDto {
    /**
     * 平台名
     */
    private String platform;
    /**
     * 模式名
     */
    private String strategy;
    /**
     * 数据类型码
     */
    private MetricTypeEnum type;
    /**
     * 信息
     */
    private String msg;

    /**
     * 数据
     */
    private Object data;

    public static MetricLogDtoBuilder newBuiler() {
        return new MetricLogDtoBuilder();
    }

    @Override
    public String toString() {
        return "MetricLogDto{" +
                "platform='" + platform + '\'' +
                ", strategy='" + strategy + '\'' +
                ", type=" + type +
                ", msg='" + msg + '\'' +
                ", data=" + data +
                '}';
    }

    public Object getData() {
        return data;
    }

    public void setData(Object data) {
        this.data = data;
    }

    public String getPlatform() {
        return platform;
    }

    public void setPlatform(String platform) {
        this.platform = platform;
    }

    public String getStrategy() {
        return strategy;
    }

    public void setStrategy(String strategy) {
        this.strategy = strategy;
    }

    public MetricTypeEnum getType() {
        return type;
    }

    public void setType(MetricTypeEnum type) {
        this.type = type;
    }

    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }

    public static final class MetricLogDtoBuilder {
        private String platform;
        private String strategy;
        private MetricTypeEnum type;
        private String msg;
        private Object data;

        private MetricLogDtoBuilder() {
        }

        public static MetricLogDtoBuilder aMetricLogDto() {
            return new MetricLogDtoBuilder();
        }

        public MetricLogDtoBuilder platform(String platform) {
            this.platform = platform;
            return this;
        }

        public MetricLogDtoBuilder strategy(String strategy) {
            this.strategy = strategy;
            return this;
        }

        public MetricLogDtoBuilder type(MetricTypeEnum type) {
            this.type = type;
            return this;
        }

        public MetricLogDtoBuilder msg(String msg) {
            this.msg = msg;
            return this;
        }

        public MetricLogDtoBuilder data(Object data) {
            this.data = data;
            return this;
        }

        public MetricLogDto build() {
            MetricLogDto metricLogDto = new MetricLogDto();
            metricLogDto.setPlatform(platform);
            metricLogDto.setStrategy(strategy);
            metricLogDto.setType(type);
            metricLogDto.setMsg(msg);
            metricLogDto.setData(data);
            return metricLogDto;
        }
    }
}
