/*
 * The MIT License (MIT)
 *
 * Copyright © 2023 xrv <xrv@live.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.tzld.crawler.etl.service;

import com.google.common.collect.ImmutableMap;
import com.google.common.collect.Maps;
import com.tzld.commons.aliyun.log.AliyunLogManager;
import com.tzld.crawler.etl.model.dto.MetricLogDto;
import com.tzld.crawler.etl.util.JsonUtil;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.Executor;
import java.util.concurrent.Executors;

/**
 * @author ehlxr
 * @since 2023-06-19 19:41.
 */
@Component
public class SlsService {
    private final AliyunLogManager aliyunLogManager;
    @Value("${aliyun.log.logstore.crawler:}")
    private String crawlerLogstore;
    @Value("${aliyun.log.logstore.metric:}")
    private String metricLogstore;
    @Value("${aliyun.log.project:}")
    private String logProject;

    private Executor pool;

    public SlsService(AliyunLogManager aliyunLogManager) {
        this.aliyunLogManager = aliyunLogManager;
    }

    @PostConstruct
    public void init() {
        pool = Executors.newFixedThreadPool(2);
    }

    public void metric(MetricLogDto logDto, String logStore) {
        Map<String, Object> map = JsonUtil.obj2Map(logDto);
        pool.execute(() -> aliyunLogManager.sendLog(logProject, logStore, "", map));
    }

    public void metric(MetricLogDto logDto) {
        metric(logDto, metricLogstore);
    }

    public void log(Map<String, Object> param) {
        HashMap<String, Object> map = Maps.newHashMap(param);
        map.put("timestamp", System.currentTimeMillis() / 1000);
        pool.execute(() -> aliyunLogManager.sendLog(logProject, crawlerLogstore, "", map));
    }

    public void log(String k1, Object v1) {
        log(ImmutableMap.of(k1, v1));
    }

    public void log(String k1, Object v1, String k2, Object v2) {
        log(ImmutableMap.of(k1, v1, k2, v2));
    }

    public void log(String k1, Object v1, String k2, Object v2, String k3, Object v3) {
        log(ImmutableMap.of(k1, v1, k2, v2, k3, v3));
    }

    public void log(String k1, Object v1, String k2, Object v2, String k3, Object v3, String k4, Object v4) {
        log(ImmutableMap.of(k1, v1, k2, v2, k3, v3, k4, v4));
    }

    public void log(String k1, Object v1, String k2, Object v2, String k3, Object v3, String k4, Object v4, String k5, Object v5) {
        log(ImmutableMap.of(k1, v1, k2, v2, k3, v3, k4, v4, k5, v5));
    }
}
