/*
 * The MIT License (MIT)
 *
 * Copyright © 2022 xrv <xrg@live.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.tzld.crawler.etl.service.feign.fallback;

import com.tzld.crawler.etl.common.base.CommonResponse;
import com.tzld.crawler.etl.common.enums.ExceptionEnum;
import com.tzld.crawler.etl.model.param.CrawlerVideoSendParam;
import com.tzld.crawler.etl.model.vo.WxVideoVO;
import com.tzld.crawler.etl.service.feign.LongVideoFeign;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cloud.openfeign.FallbackFactory;
import org.springframework.stereotype.Service;

/**
 * @author ehlxr
 * @since 2022-10-10 11:43.
 */
@Service
public class LongVideoFeignFallbackFactory implements FallbackFactory<LongVideoFeignFallback> {
    @Override
    public LongVideoFeignFallback create(Throwable cause) {
        return new LongVideoFeignFallback(cause);
    }
}

class LongVideoFeignFallback implements LongVideoFeign {
    private final Logger log = LoggerFactory.getLogger(this.getClass());
    private final Throwable th;

    LongVideoFeignFallback(Throwable th) {
        this.th = th;
    }

    @Override
    public CommonResponse<WxVideoVO> crawlerVideoSend(CrawlerVideoSendParam request) {
        CommonResponse<WxVideoVO> response = new CommonResponse<>();
        response.setMsg(th.getMessage());
        response.setCode(ExceptionEnum.INVOKE_VIDEOAPI_ERROR.getCode());

        log.error("request: {}, error: {}", request, th.getMessage());
        return response;
    }
}
