/*
 * The MIT License (MIT)
 *
 * Copyright © 2023 xrv <xrv@live.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.tzld.crawler.etl.util;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.google.common.collect.ImmutableMap;
import com.google.common.collect.Lists;

import java.util.List;

/**
 * @author ehlxr
 * @since 2023-06-19 14:55.
 */
public class FeishuUtils {
    private static String fetchFeishuToken(String feishuAppid, String feishuAppsecret) {
        String tokenResp = HttpUtil.post("https://open.feishu.cn/open-apis/auth/v3/tenant_access_token/internal",
                JsonUtil.obj2String(ImmutableMap.of("app_id", feishuAppid, "app_secret", feishuAppsecret)));
        return JSONObject.parseObject(tokenResp).getString("tenant_access_token");
    }

    public static String insertRows(String appId, String appSecret, String sheetToken, String sheetId, int startIndex, int endIndex) {
        return HttpUtil.post("https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/" + sheetToken + "/insert_dimension_range",
                ImmutableMap.of("Authorization", String.format("Bearer %s", fetchFeishuToken(appId, appSecret))),
                JsonUtil.obj2String(ImmutableMap.of("inheritStyle", "AFTER", "dimension",
                        ImmutableMap.of("sheetId", sheetId, "majorDimension", "ROWS",
                                "startIndex", startIndex, "endIndex", endIndex))));
    }

    public static String updateValues(String appId, String appSecret, String sheetToken, String range, List<List<Object>> values) {
        return HttpUtil.post("https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/" + sheetToken + "/values_batch_update",
                ImmutableMap.of("Authorization", String.format("Bearer %s", fetchFeishuToken(appId, appSecret))),
                JsonUtil.obj2String(ImmutableMap.of("valueRanges",
                        Lists.newArrayList(ImmutableMap.of("range", range, "values", values)))));
    }

    public static JSONArray getValues(String appId, String appSecret, String sheetToken, String sheetId, String range) {
        try {
            String dataResp = HttpUtil.get(
                    String.format("https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/%s/values/%s!%s?&dateTimeRenderOption=FormattedString",
                            sheetToken, sheetId, range),
                    ImmutableMap.of("Authorization", String.format("Bearer %s", fetchFeishuToken(appId, appSecret))));
            return JSONObject.parseObject(dataResp)
                    .getJSONObject("data")
                    .getJSONObject("valueRange")
                    .getJSONArray("values");
        } catch (Exception e) {
            throw new RuntimeException("读取飞书文档数据失败.", e);
        }
    }

}
